@@ -108,7 +108,7 @@ class ProvisionStackTask(
             apis.append(f"cloudformation.list_stacks_{self.account_id}_{self.region}")
 
         if len(self.ssm_param_outputs) > 0:
-            apis.append(f"ssm.put_parameter_and_wait_{self.region}")
+            apis.append(f"ssm.put_parameter_and_wait")
 
         return apis
 
